@@ -5,19 +5,21 @@ simAdd <- function(newdata, mu, parameter, covtype, Cl, iso=FALSE, eps.R = 1e-08
   nCl <- length(Cl)
   if (length(iso)==1) 
     iso <- rep(iso,nCl)
-  parameter <- paramList2Vect(parameter, Cl, iso)
+  parameter <- fanovaGraph:::paramList2Vect(parameter, Cl, iso)
   alpha <- parameter[1:nCl]
   theta <- parameter[-(1:nCl)]
   thetalist <- Cl
   # building thetalist:
   ntemp <- 0
   nClani <- nCl - sum(iso)
-  for (j in (1:nClani)) {
+  # for (j in (1:nClani)) { # DOES NOT RESPECT ORDER
+  for (j in (1:nCl)[!iso]){
     thetalist[[j]] <- theta[(ntemp + 1):(ntemp + length(Cl[[j]]))]
     ntemp <- ntemp + length(Cl[[j]])
   }
   if (nClani < nCl) {
-    for (j in ((nClani + 1):nCl)) {
+  # for (j in ((nClani + 1):nCl)) { # DOES NOT RESPECT ORDER
+    for (j in (1:nCl)[iso]) {
       thetalist[[j]] <- theta[ntemp]
       ntemp <- ntemp + 1
     }
